@@ -19,8 +19,8 @@ extern "C" {
  */
 
 /** Interface version */
-#define HD_VERSION		23
-#define HD_MINOR_VERSION	3
+#define HD_VERSION		24
+#define HD_MINOR_VERSION	0
 #define HD_FULL_VERSION		(HD_VERSION * 1000 + HD_MINOR_VERSION)
 
 /**
@@ -116,7 +116,7 @@ typedef enum probe_feature {
   pr_modem_usb, pr_parallel, pr_parallel_lp, pr_parallel_zip, pr_isa,
   pr_isa_isdn, pr_isdn, pr_kbd, pr_prom, pr_sbus, pr_int, pr_braille,
   pr_braille_alva, pr_braille_fhp, pr_braille_ht, pr_ignx11, pr_sys,
-  pr_bios_vbe, pr_isapnp_old, pr_isapnp_new, pr_isapnp_mod, pr_braille_baum,
+  pr_bios_vbe, pr_no_remove, pr_loose_match, pr_isapnp_mod, pr_braille_baum,
   pr_manual, pr_fb, pr_veth, pr_pppoe, pr_scan, pr_pcmcia, pr_fork,
   pr_parallel_imm, pr_s390, pr_cpuemu, pr_sysfs, pr_s390disks, pr_udev,
   pr_block, pr_block_cdrom, pr_block_part, pr_edd, pr_edd_mod, pr_bios_ddc,
@@ -168,7 +168,7 @@ typedef enum base_classes {
   bc_storage_device, bc_network_interface, bc_keyboard, bc_printer,
   bc_hub, bc_braille, bc_scanner, bc_joystick, bc_chipcard, bc_camera,
   bc_framebuffer, bc_dvb, bc_tv, bc_partition, bc_dsl, bc_bluetooth, bc_fingerprint,
-  bc_mmc_ctrl
+  bc_mmc_ctrl, bc_touchpad
 } hd_base_classes_t;
 
 /** subclass values of bc_monitor */
@@ -1483,6 +1483,26 @@ typedef struct {
   char *platform;		/**< x86: NULL */
   str_list_t *features;		/**< x86: flags */
   double bogo;			/**< bogo mips */
+
+  // x86 only
+  unsigned physical_id;
+  unsigned siblings;
+  unsigned core_id;
+  unsigned cores;
+  unsigned apicid;
+  unsigned apicid_initial;
+  unsigned fpu:1;
+  unsigned fpu_exception:1;
+  unsigned cpuid_level;
+  unsigned write_protect:1;
+  unsigned tlb_size;
+  unsigned clflush_size;
+  int cache_alignment;
+  unsigned address_size_physical;
+  unsigned address_size_virtual;
+
+  str_list_t *bugs;
+  str_list_t *power_management;
 } cpu_info_t;
 
 
